Enum escape_bytes::EscapeIntoError
source · pub enum EscapeIntoError {
OutOfBounds,
}Expand description
Escape into error occurs when escaping into a slice cannot continue.
Variants
OutOfBounds
Writing into the slice would write to a position that is out-of-bounds.