pub enum UnescapeError {
InvalidEscape,
InvalidHexHi,
InvalidHexLo,
}Expand description
Unescape error occurs when encountering unexpected byte sequences.
Variants
InvalidEscape
An escape backslash character (\) was followed by a character that was
not a \, 0, t, r, n, or x.
InvalidHexHi
An escape backslash character and x indicating a hex escape (\x) were
followed by a character that was not a valid hex character
(0123456789abcdef).
InvalidHexLo
An escape backslash character, x indicating a hex escape, and the hi
nibble (\xN) were followed by a character that was not a valid hex
character (0123456789abcdef).