Function escape_bytes::escaped_max_len
source · pub const fn escaped_max_len(len: usize) -> Option<usize>Expand description
Returns the maximum escaped length of the given unescaped length.
pub const fn escaped_max_len(len: usize) -> Option<usize>Returns the maximum escaped length of the given unescaped length.